Documentation
¶
Overview ¶
Package imageutil provides image processing utilities for OCR.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetDimensions ¶
GetDimensions returns the width and height of an image file.
func SaveSlices ¶
SaveSlices writes slices to a subdirectory next to the original image. The directory is named after the image file (without extension). Files are named 001.jpg, 002.jpg, etc. Returns the directory path.
Types ¶
Click to show internal directories.
Click to hide internal directories.